@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: connection
 version: 0.2.5
-id: connection-0.2.5-b1d9e33e03618093afb3c4e9d40c147e
-key: conne_8NDWikwRg6A9LPcaOH8C9E
+id: connection-0.2.5-a80bc1c6fc57feb339146a3820d4e5af
+key: conne_CUhiEWoO3pN1zENG1yqVrC
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -27,7 +27,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/connection-0.2.5
-hs-libraries: HSconnection-0.2.5-8NDWikwRg6A9LPcaOH8C9E
+hs-libraries: HSconnection-0.2.5-CUhiEWoO3pN1zENG1yqVrC
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
@@ -35,8 +35,8 @@ depends:
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    socks-0.5.4-8c65994a52c136dee4fd43556a5ac65b
-    tls-1.3.5-cc53341e73a1ad5e4154c36129b6c569
+    socks-0.5.5-0c45c80c2330de843f6569e694fbea7d
+    tls-1.3.8-96444b4e688bece54c4ea4192a68b9a3
     x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
     x509-store-1.6.1-43851738bccd019b67ff937f268f43a7
     x509-system-1.6.3-c8b329776e9eeee116761552f3bd6b7a
